<?php

/**
 * JC setup.
 *
 * Sets up theme defaults and registers the various WordPress features that
 * JC supports.
 */
function jc_setup() {
	add_theme_support( 'title-tag' );
	add_theme_support( 'widgets' );

	// Indicate widget sidebars can use selective refresh in the Customizer.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'jc' ) );
}
add_action( 'after_setup_theme', 'jc_setup' );

/**
 * Enqueue scripts and styles.
 */
function jc_scripts() {

  $theme = wp_get_theme();
  $version = $theme->get( 'Version' );

	// Loads our main stylesheet.
	wp_enqueue_style( 'jc-style', get_stylesheet_uri(), array(), $version );

  // bootstrap stylesheet
  wp_enqueue_style( 'style', 'https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.2/css/bootstrap.min.css', array(), '5.3.2' );

	// jquery
	wp_deregister_script( 'jquery' );
	wp_register_script( 'jquery', 'https://cdnjs.cloudflare.com/ajax/libs/jquery/3.7.1/jquery.min.js', array(), '3.7.1', false );
	wp_enqueue_script( 'jquery' );

	// bootstrap js
	wp_enqueue_script( 'bootstrap-js', 'https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.2/js/bootstrap.bundle.min.js', array(), '5.3.2', true );

	// bundled
	wp_enqueue_script( 'bundled', get_template_directory_uri() . '/js/bundled.js', array( 'jquery' ), $version, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_deregister_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'jc_scripts' );

/**
 * Register sidebars.
 *
 */
function jc_widgets_init() {
	// 底部友情链接
	register_sidebar(
		array(
			'name'          => __( 'Links', 'jc' ),
			'id'            => 'footer-1',
			'description'   => __( 'Friendship link at the bottom', 'jc' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
}
add_action( 'widgets_init', 'jc_widgets_init' );

/**
 * Carbon Fields
 * https://docs.carbonfields.net/
 */
use Carbon_Fields\Container;
use Carbon_Fields\Field;

add_action( 'carbon_fields_register_fields', 'crb_attach_theme_options' );
function crb_attach_theme_options() {
	Container::make( 'theme_options', __( 'Theme Options' ) )
		->add_fields( array(
      Field::make('text', 'crb_headline_title', __('首页口号')),
      Field::make('textarea', 'crb_headline_desc', '宣传语'),
			Field::make( 'checkbox', 'crb_alert_logic', 'Display Alert' ),
			Field::make( 'textarea', 'crb_alert_content', 'Alert Content' )
			->set_conditional_logic( array(
        array(
            'field' => 'crb_alert_logic',
            'value' => true,
        ))
			),
      Field::make('complex', 'crb_cases', __('首页方案'))
        ->add_fields(array(
          Field::make('text', 'title', __('名称')),
          Field::make('text', 'price', __('价格')),
          Field::make('text', 'sub_title', __('小标题')),
          Field::make('textarea', 'content', __('内容')),
          Field::make('text', 'link', __('链接')),
        )),
		));
}

add_action( 'after_setup_theme', 'crb_load' );
function crb_load() {
	require_once( 'vendor/autoload.php' );
	\Carbon_Fields\Carbon_Fields::boot();
}
